# -*- coding: utf-8 -*-

"""

  test tests
  ~~~~~~~~~~

  tests, well, the upper class structure that powers unit and
  integration testing stuff.

  :author: Sam Gammon <sg@samgammon.com>
  :copyright: (c) Sam Gammon, 2014
  :license: This software makes use of the MIT Open Source License.
            A copy of this license is included as ``LICENSE.md`` in
            the root of the project.

"""
